@@ -1,11 +1,14 @@
-#' Get or view the names of available plotting functions
+#' Get or view the names of available plotting or data functions
 #'
 #' @export
 #' @param pattern,fixed,invert Passed to [base::grep()].
+#' @param plots_only If `TRUE` (the default) only plotting functions are
+#'   searched for. If `FALSE` then functions that return data for plotting
+#'   (functions ending in `_data()`) are also included.
 #' @return A possibly empty character vector of function names with several
 #'   additional attributes (for use by a custom print method). If `pattern`
 #'   is missing then the returned object contains the names of all available
-#'   plotting functions in the [MCMC] or [PPC] module, depending on
+#'   plotting functions in the [MCMC], [PPC], or [PPD] module, depending on
 #'   which function is called. If `pattern` is specified then a subset of
 #'   function names is returned.
 #'
@@ -13,24 +16,67 @@
 #' available_mcmc()
 #' available_mcmc("nuts")
 #' available_mcmc("rhat|neff")
+#'
+#' available_ppc()
 #' available_ppc("grouped")
 #' available_ppc("grouped", invert = TRUE)
 #'
-available_ppc <- function(pattern, fixed = FALSE, invert = FALSE) {
-  .list_module_functions("ppc",
-                         .pattern = pattern,
-                         fixed = fixed,
-                         invert = invert)
-}
+#' available_ppd()
+#' available_ppd("grouped")
+#'
+#' # can also see which functions that return data are available
+#' available_ppc(plots_only = FALSE)
+#'
+#' # only show the _data functions
+#' available_ppc("_data", plots_only = FALSE)
+#' available_ppd("_data", plots_only = FALSE)
+#' available_mcmc("_data", plots_only = FALSE)
+#'
+available_ppc <-
+  function(pattern = NULL,
+           fixed = FALSE,
+           invert = FALSE,
+           plots_only = TRUE) {
+    .list_module_functions(
+      .module = "ppc",
+      .pattern = pattern,
+      fixed = fixed,
+      invert = invert,
+      plots_only = plots_only
+    )
+  }
 
 #' @rdname available_ppc
 #' @export
-available_mcmc <- function(pattern, fixed = FALSE, invert = FALSE) {
-  .list_module_functions("mcmc",
-                         .pattern = pattern,
-                         fixed = fixed,
-                         invert = invert)
-}
+available_ppd <-
+  function(pattern = NULL,
+           fixed = FALSE,
+           invert = FALSE,
+           plots_only = TRUE) {
+    .list_module_functions(
+      .module = "ppd",
+      .pattern = pattern,
+      fixed = fixed,
+      invert = invert,
+      plots_only = plots_only
+    )
+  }
+
+#' @rdname available_ppc
+#' @export
+available_mcmc <-
+  function(pattern = NULL,
+           fixed = FALSE,
+           invert = FALSE,
+           plots_only = TRUE) {
+    .list_module_functions(
+      .module = "mcmc",
+      .pattern = pattern,
+      fixed = fixed,
+      invert = invert,
+      plots_only = plots_only
+    )
+  }
 
 #' @export
 print.bayesplot_function_list <- function(x, ...) {
@@ -48,15 +94,13 @@ print.bayesplot_function_list <- function(x, ...) {
 
 # internal ----------------------------------------------------------------
 .list_module_functions <-
-  function(.module = c("ppc", "mcmc"),
+  function(.module = c("ppc", "ppd", "mcmc"),
            .pattern,
            fixed = FALSE,
-           invert = FALSE) {
+           invert = FALSE,
+           plots_only = TRUE) {
 
     .module <- match.arg(.module)
-    if (missing(.pattern)) {
-      .pattern <- NULL
-    }
 
     all_funs <- grep(
       pattern = paste0("^", .module, "_"),
@@ -65,6 +109,17 @@ print.bayesplot_function_list <- function(x, ...) {
     )
     return_funs <- sort(all_funs)
 
+    if (plots_only) {
+      # drop _data() functions
+      return_funs <-
+        grep(
+          pattern = "_data()",
+          x = return_funs,
+          invert = TRUE,
+          value = TRUE
+        )
+    }
+
     if (!is.null(.pattern)) {
       return_funs <- grep(
         pattern = .pattern,
@@ -74,6 +129,7 @@ print.bayesplot_function_list <- function(x, ...) {
         invert = invert
       )
     }
+
     structure(
       return_funs,
       class = c("bayesplot_function_list", "character"),
